﻿using C1.WPF.DataGrid;
using System;
using System.Collections.ObjectModel;
using System.Data;
using System.Windows;
using System.Windows.Controls;

namespace C1DataGridComboxSource
{
    /// <summary>
    /// Interaktionslogik für MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public DataView SourceDataView
        {
            get { return (DataView)GetValue(SourceDataViewProperty); }
            set { SetValue(SourceDataViewProperty, value); }
        }

        // Using a DependencyProperty as the backing store for SourceDataView.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty SourceDataViewProperty =
            DependencyProperty.Register("SourceDataView", typeof(DataView), typeof(MainWindow), new PropertyMetadata(null));


        public MainWindow()
        {
            InitializeComponent();

            ObservableCollection<DataDummy> dataDummies = new ObservableCollection<DataDummy>();
            DataDummy a = new DataDummy() { ID = 1};
            DataDummy b = new DataDummy() { ID = 2 };
            DataDummy c = new DataDummy() { ID = 3 };
            dataDummies.Add(a);
            dataDummies.Add(b);
            dataDummies.Add(c);
          

            DataTable cbxSource = new DataTable();
            cbxSource.Columns.Add(new DataColumn("ID", typeof(int)));
            cbxSource.Columns[0].DefaultValue = -1;
            cbxSource.Columns.Add(new DataColumn("Label", typeof(string)));
            cbxSource.Rows.Add(1, "Message I");
            cbxSource.Rows.Add(2, "Message II");
            cbxSource.Rows.Add(3, "Message III");
            this.SourceDataView = cbxSource.DefaultView;
            this.SourceDataView.ListChanged += SourceDataView_ListChanged;
            C1Datagrid.ItemsSource = dataDummies;
            MSDatagrid.ItemsSource = dataDummies;
        }

        private void SourceDataView_ListChanged(object sender, System.ComponentModel.ListChangedEventArgs e)
        {
            C1Datagrid.Refresh();
        }

        private void C1Datagrid_LoadingRow(object sender, C1.WPF.DataGrid.DataGridRowEventArgs e)
        {
            var dg = sender as C1DataGrid;
            if(!(e.Row.DataItem is DataDummy) && e.Row.Type == DataGridRowType.Item)
            {
                e.Row.Visibility = Visibility.Collapsed;
            }
        }
    }

    public class DataDummy 
    {
        public DataDummy() 
        {
        }
        public int? ID { get; set; }
    }

    public class WPFBindingHelper : Freezable
    {
        protected override Freezable CreateInstanceCore()
        {
            return new WPFBindingHelper();
        }



        public object Data
        {
            get { return (object)GetValue(DataProperty); }
            set { SetValue(DataProperty, value); }
        }

        // Using a DependencyProperty as the backing store for PpprlModel.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty DataProperty =
            DependencyProperty.Register("Data", typeof(object), typeof(WPFBindingHelper), new PropertyMetadata(null));
    }
}
